@@ -160,7 +160,7 @@ class GbpOptionParser(OptionParser):
                 'renumber': 'False',
                 'notify': 'auto',
                 'merge': 'True',
-                'merge-mode': 'merge',
+                'merge-mode': 'auto',
                 'track': 'True',
                 'author-is-committer': 'False',
                 'author-date-is-committer-date': 'False',
@@ -213,7 +213,7 @@ class GbpOptionParser(OptionParser):
             "Format string for commit message used to commit "
             "the upstream tarball, default is '%(import-msg)s'",
         'commit-msg':
-            "Format string for commit messag used to commit, "
+            "Format string for commit message used to commit, "
             "the changelog, default is '%(commit-msg)s'",
         'pristine-tar':
             "Use pristine-tar to create orig tarball, "
@@ -292,7 +292,7 @@ class GbpOptionParser(OptionParser):
             "After the import merge the result to the debian branch, "
             "default is '%(merge)s'",
         'merge-mode':
-            "Howto merge the new upstream sources onto the debian branch"
+            "Howto merge the new upstream sources onto the debian branch, "
             "default is '%(merge-mode)s'",
         'track':
             "Set up tracking for remote branches, "
@@ -315,8 +315,8 @@ class GbpOptionParser(OptionParser):
         'hooks':
             "Enable running all hooks, default is %(hooks)s",
         'time-machine':
-            "don't try head commit only to apply the patch queue "
-            "but look TIME_MACHINE commits back, "
+            "don't try to apply patch queue to head commit only. "
+            "Try at most TIME_MACHINE commits back, "
             "default is '%(time-machine)d'",
         'pbuilder-autoconf':
             "Whether to configure pbuilder automatically, "
@@ -328,13 +328,13 @@ class GbpOptionParser(OptionParser):
             "Template directory used by git init, "
             "default is '%(template-dir)s'",
         'remote-config':
-            "Remote defintion in gbp.conf used to create the remote "
+            "Remote definition in gbp.conf used to create the remote "
             "repository, default is '%(remote-config)s'",
         'allow-unauthenticated':
             "Don't verify integrity of downloaded source, "
             "default is '%(allow-unauthenticated)s'",
         'symlink-orig':
-            "Whether to creat a symlink from the upstream tarball "
+            "Whether to create a symlink from the upstream tarball "
             "to the orig.tar.gz if needed, default is "
             "'%(symlink-orig)s'",
         'purge':
