@@ -20,6 +20,7 @@ from gbp.pkg import compressor_opts
 from gbp.pkg.pristinetar import PristineTar
 from gbp.deb import DebianPkgPolicy
 
+
 class DebianPristineTar(PristineTar):
     """The pristine-tar branch in a Debian git repository"""
     def has_commit(self, package, version, comp_type=None):
@@ -43,7 +44,7 @@ class DebianPristineTar(PristineTar):
 
         return super(DebianPristineTar, self).has_commit(name_regexp)
 
-    def checkout(self, package, version, comp_type, output_dir, subtarball=None):
+    def checkout(self, package, version, comp_type, output_dir, component=None):
         """
         Checkout the orig tarball for package I{package} of I{version} and
         compression type I{comp_type} to I{output_dir}
@@ -61,6 +62,5 @@ class DebianPristineTar(PristineTar):
                                                   version,
                                                   comp_type,
                                                   output_dir,
-                                                  subtarball=subtarball)
+                                                  component=component)
         super(DebianPristineTar, self).checkout(name)
-
