@@ -306,6 +306,8 @@ def is_download(pkg):
     """
     >>> is_download("http://foo.example.com/apackage.dsc")
     (True, 'http://foo.example.com/apackage.dsc')
+    >>> is_download("apt:///apackage/sid")
+    (True, 'apackage/sid')
     >>> is_download("apt://apackage/sid")
     (True, 'apackage/sid')
     >>> is_download("apt_1.0_amd64.dsc")
@@ -316,7 +318,7 @@ def is_download(pkg):
     if pkg.startswith('file://'):
         return (False, pkg[len('file://'):])
     elif pkg.startswith('apt://'):
-        return (True, pkg[len('apt://'):])
+        return (True, pkg[len('apt://'):].lstrip('/'))
     elif re.match("[a-z]{1,5}://", pkg):
         return (True, pkg)
     return (False, pkg)
@@ -469,10 +471,6 @@ def main(argv):
             if not src.native:
                 if is_empty:
                     repo.create_branch(options.upstream_branch, commit)
-                if options.pristine_tar:
-                    repo.create_pristinetar_commits(options.upstream_branch,
-                                                    src.tgz,
-                                                    src.additional_tarballs.items())
             if (not repo.has_branch(options.debian_branch) and
                     (is_empty or options.create_missing_branches)):
                 repo.create_branch(options.debian_branch, commit)
@@ -485,6 +483,10 @@ def main(argv):
         if repo.get_branch() == options.debian_branch or is_empty:
             # Update HEAD if we modified the checked out branch
             repo.force_head(options.debian_branch, hard=True)
+        if options.pristine_tar and not src.native:
+            repo.create_pristinetar_commits(options.upstream_branch,
+                                            src.tgz,
+                                            src.additional_tarballs.items())
     except KeyboardInterrupt:
         ret = 1
         gbp.log.err("Interrupted. Aborting.")
