@@ -24,6 +24,7 @@ import tempfile
 import time
 import gbp.command_wrappers as gbpc
 from gbp.deb import (DebianPkgPolicy, parse_changelog_repo)
+from gbp.deb.format import DebianSourceFormat
 from gbp.deb.upstreamsource import DebianUpstreamSource, unpack_component_tarball
 from gbp.deb.uscan import (Uscan, UscanError)
 from gbp.deb.changelog import ChangeLog, NoChangeLogError
@@ -32,6 +33,7 @@ from gbp.config import GbpOptionParserDebian, GbpOptionGroup, no_upstream_branch
 from gbp.errors import GbpError
 from gbp.pkg import parse_archive_filename
 from gbp.format import format_str
+from gbp.git.vfs import GitVfs
 import gbp.log
 from gbp.scripts.common import ExitCodes, is_download
 from gbp.scripts.common.import_orig import (orig_needs_repack, cleanup_tmp_tree,
@@ -131,8 +133,11 @@ class ImportOrigDebianGitRepository(DebianGitRepository):
                     gbp.log.info('Rolling back branch %s by resetting it to %s' % (name, sha))
                     self.update_ref("refs/heads/%s" % name, sha, msg="gbp import-orig: failure rollback of %s" % name)
                 elif action == 'abortmerge':
-                    gbp.log.info('Rolling back failed merge of %s' % name)
-                    self.abort_merge()
+                    if self.is_in_merge():
+                        gbp.log.info('Rolling back failed merge of %s' % name)
+                        self.abort_merge()
+                    else:
+                        gbp.log.info("Nothing to rollback for merge of '%s'" % name)
                 else:
                     raise GitRepositoryError("Don't know how to %s %s %s" % (action, reftype, name))
             except GitRepositoryError as e:
@@ -315,6 +320,9 @@ def debian_branch_merge(repo, tag, version, options):
     except KeyError:
         raise GbpError("%s is not a valid merge mode" % options.merge_mode)
     func(repo, tag, version, options)
+
+
+def postimport_hook(repo, tag, version, options):
     if options.postimport:
         epoch = ''
         if os.access('debian/changelog', os.R_OK):
@@ -336,6 +344,24 @@ def debian_branch_merge(repo, tag, version, options):
              extra_env=env)()
 
 
+def is_30_quilt(repo, options):
+    format_file = DebianSourceFormat.format_file
+    try:
+        content = GitVfs(repo, options.debian_branch).open(format_file).read()
+    except IOError:
+        return False
+    return str(DebianSourceFormat(content)) == "3.0 (quilt)"
+
+
+def debian_branch_merge_by_auto(repo, tag, version, options):
+    if is_30_quilt(repo, options):
+        gbp.log.debug("3.0 (quilt) package, replacing debian/ dir")
+        return debian_branch_merge_by_replace(repo, tag, version, options)
+    else:
+        gbp.log.debug("not 3.0 (quilt) package, using git merge")
+        return debian_branch_merge_by_merge(repo, tag, version, options)
+
+
 def debian_branch_merge_by_replace(repo, tag, version, options):
     gbp.log.info("Replacing upstream source on '%s'" % options.debian_branch)
 
@@ -361,6 +387,17 @@ def debian_branch_merge_by_replace(repo, tag, version, options):
     repo.force_head(commit, hard=True)
 
 
+def debian_branch_merge_by_merge(repo, tag, version, options):
+    gbp.log.info("Merging to '%s'" % options.debian_branch)
+    branch = repo.get_branch()
+    repo.set_branch(options.debian_branch)
+    try:
+        repo.merge(tag)
+    except GitRepositoryError:
+        raise GbpError("Automatic merge failed.")
+    repo.set_branch(branch)
+
+
 def get_component_tarballs(name, version, tarball, components):
     """
     Figure out the paths to the component tarballs based on the main
@@ -380,15 +417,20 @@ def get_component_tarballs(name, version, tarball, components):
     return tarballs
 
 
-def debian_branch_merge_by_merge(repo, tag, version, options):
-    gbp.log.info("Merging to '%s'" % options.debian_branch)
-    branch = repo.get_branch()
-    repo.set_branch(options.debian_branch)
-    try:
-        repo.merge(tag)
-    except GitRepositoryError:
-        raise GbpError("Automatic merge failed.")
-    repo.set_branch(branch)
+def unpack_tarballs(sourcepackage, source, version, component_tarballs, options):
+    tmpdir = tempfile.mkdtemp(dir='../')
+    if not source.is_dir():  # Unpack main tarball
+        source.unpack(tmpdir, options.filters)
+        gbp.log.debug("Unpacked '%s' to '%s'" % (source.path, source.unpacked))
+
+    if orig_needs_repack(source, options):
+        gbp.log.debug("Filter pristine-tar: repacking '%s' from '%s'" % (source.path, source.unpacked))
+        (source, tmpdir) = repack_source(source, sourcepackage, version, tmpdir, options.filters)
+
+    if not source.is_dir():  # Unpack component tarballs
+        for (component, tarball) in component_tarballs:
+            unpack_component_tarball(source.unpacked, component, tarball, options.filters)
+    return (source, tmpdir)
 
 
 def set_bare_repo_options(options):
@@ -460,12 +502,10 @@ def build_parser(name):
     parser.add_config_file_option(option_name="color", dest="color", type='tristate')
     parser.add_config_file_option(option_name="color-scheme",
                                   dest="color_scheme")
-
-    # Accepted for compatibility
-    parser.add_option("--no-dch", dest='no_dch', action="store_true",
-                      default=False, help="deprecated - don't use.")
     parser.add_option("--uscan", dest='uscan', action="store_true",
                       default=False, help="use uscan(1) to download the new tarball.")
+
+    # Accepted for compatibility
     parser.add_option("--download", dest='download', action="store_true",
                       default=False, help="Ignored. Accepted for compatibility.")
     return parser
@@ -483,9 +523,6 @@ def parse_args(argv):
     (options, args) = parser.parse_args(argv[1:])
     gbp.log.setup(options.color, options.verbose, options.color_scheme)
 
-    if options.no_dch:
-        gbp.log.warn("'--no-dch' passed. This is now the default, please remove this option.")
-
     if options.download:
         gbp.log.warn("Passing --download explicitly is deprecated.")
 
@@ -495,7 +532,7 @@ def parse_args(argv):
 
 def main(argv):
     ret = 0
-    tmpdir = ''
+    tmpdir = None
     pristine_orig = None
     linked = False
     repo = None
@@ -543,18 +580,7 @@ def main(argv):
         if repo.bare:
             set_bare_repo_options(options)
 
-        if not source.is_dir():  # Unpack main tarball
-            tmpdir = tempfile.mkdtemp(dir='../')
-            source.unpack(tmpdir, options.filters)
-            gbp.log.debug("Unpacked '%s' to '%s'" % (source.path, source.unpacked))
-
-        if orig_needs_repack(source, options):
-            gbp.log.debug("Filter pristine-tar: repacking '%s' from '%s'" % (source.path, source.unpacked))
-            (source, tmpdir) = repack_source(source, sourcepackage, version, tmpdir, options.filters)
-
-        if not source.is_dir():  # Unpack component tarballs
-            for (component, tarball) in component_tarballs:
-                unpack_component_tarball(source.unpacked, component, tarball, options.filters)
+        source, tmpdir = unpack_tarballs(sourcepackage, source, version, component_tarballs, options)
 
         (pristine_orig, linked) = prepare_pristine_tar(source.path,
                                                        sourcepackage,
@@ -607,6 +633,7 @@ def main(argv):
             elif options.merge:
                 repo.rrr_branch(options.debian_branch)
                 debian_branch_merge(repo, tag, version, options)
+                postimport_hook(repo, tag, version, options)
 
             # Update working copy and index if we've possibly updated the
             # checked out branch
